/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * $Id: MailSenderWrapper.java 7848 2011-03-21 09:56:53Z danesa $
 */
package org.ow2.jasmine.monitoring.eventswitch.endpoints;

import java.io.IOException;

import javax.mail.Message;
import javax.mail.MessagingException;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;
import javax.naming.NamingException;

import org.ow2.jasmine.event.messages.JasmineEventNotificationMail;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * @author poutchjp
 */
public class MailSenderWrapper extends MuleEJB3Wrapper<Session> {

    /**
     * Logger.
     */
    private Log logger = LogFactory.getLog(this.getClass());

    /**
     * Starts the {@link MuleEJB3Wrapper} in deferred mode.
     */
    public MailSenderWrapper() {
        super(true);
    }

    /**
     * Send a JasmineEventNotification.
     * @param event the event to save
     */
    public void sendJasmineEventNotification(final JasmineEventNotificationMail notificationEventMail) {

        ClassLoader currentClassLoader = Thread.currentThread().getContextClassLoader();
        Thread.currentThread().setContextClassLoader(MailSenderWrapper.class.getClassLoader());

       try {
           // Set the mail properties
           Message message = new MimeMessage(getBean());
           if (notificationEventMail.getFrom() != null) {
               message.setFrom(new InternetAddress(notificationEventMail.getFrom()));
           }
           InternetAddress[] toRecipients = new InternetAddress[] {new InternetAddress(notificationEventMail.getTo())};
           message.setRecipients(Message.RecipientType.TO, toRecipients);
           if (notificationEventMail.getCc() != null) {
               InternetAddress[] ccRecipients = new InternetAddress[] {new InternetAddress(notificationEventMail.getCc())};
               message.setRecipients(Message.RecipientType.CC, ccRecipients);
           }
           if (notificationEventMail.getBcc() != null) {
               InternetAddress[] bccRecipients = new InternetAddress[] {new InternetAddress(notificationEventMail.getBcc())};
               message.setRecipients(Message.RecipientType.BCC, bccRecipients);
           }
           message.setSubject("["+notificationEventMail.getLevel()+"]"+" alarm notification");
           message.setContent(notificationEventMail.getMessage(), "text/plain");

           // Send the message
           Transport.send(message);
       } catch(MessagingException e){
           logger.warn("A failure occurs when getting a message from the session and setting the different parameters :", e.getMessage());
       } catch (NamingException e) {
           logger.warn("You have not configured the mail factory with the specified name. By default, the factory's name is mailSession_1 :", e.getMessage());
       } catch (IOException e) {
           logger.warn("You have not configured the mail factory with the specified name. By default, the factory's name is mailSession_1 :", e.getMessage());
       } finally {
           Thread.currentThread().setContextClassLoader(currentClassLoader);
       }

    }

}
