/**
 * JASMINe
 * Copyright (C) 2008-2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: WildCATUMOComponent.java 7848 2011-03-21 09:56:53Z danesa $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eventswitch.endpoints;

import java.io.IOException;

import javax.naming.NamingException;

import org.ow2.jasmine.event.beans.JasmineEventEB;
import org.ow2.jasmine.event.messages.JasmineEvent;
import org.ow2.jasmine.event.messages.JasmineEventDetails;
import org.ow2.jasmine.monitoring.eventswitch.beans.JasmineEventWildCATRemote;
import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * An UMO component to generate new WildCAT events via EJB3.
 * @author Loris Bouzonnet
 */
public class WildCATUMOComponent extends MuleEJB3Wrapper<JasmineEventWildCATRemote> {

    /**
     * Logger.
     */
    private Log logger = LogFactory.getLog(this.getClass());

    /**
     * Starts the {@link MuleEJB3Wrapper} in deferred mode.
     */
    public WildCATUMOComponent() {
        super(true);
    }

    /**
     * Generate a new event for each event detail in a JASMINe Event.
     * @param jasmineEvent JasmineEvent to save
     */
    public void saveJasmineEvent(final JasmineEvent jasmineEvent) {
        for(JasmineEventDetails jasmineEventDetails: jasmineEvent.getEvents()) {
            saveJasmineEventEB(
                    new JasmineEventEB(
                            jasmineEvent.getDomain(),
                            jasmineEvent.getServer(),
                            jasmineEventDetails.getSource(),
                            jasmineEventDetails.getProbe(),
                            jasmineEventDetails.getValue(),
                            jasmineEventDetails.getTimestamp(),
                            jasmineEventDetails.getSname()));
        }
    }

    /**
     * Generate a new event from {@link JasmineEventEB}.
     * @param jasmineEventEB a {@link JasmineEventEB} to generate a new event
     */
    public void saveJasmineEventEB(final JasmineEventEB jasmineEventEB) {
        ClassLoader currentClassLoader = Thread.currentThread().getContextClassLoader();
        Thread.currentThread().setContextClassLoader(WildCATUMOComponent.class.getClassLoader());
        try {
            getBean().generateEvent(jasmineEventEB);
        } catch (NamingException e) {
            logger.warn("EJBs are not ready ... the message is not processed");
        } catch (IOException e) {
            logger.warn("EJBs are not ready ... the message is not processed");
        } finally {
            Thread.currentThread().setContextClassLoader(currentClassLoader);
        }
    }

}
